@@ -24,9 +24,8 @@
 #include <gtkmm/buttonbox.h>
 #include "Granule-main.h"
 
-
 #ifdef IS_HILDON
-#    include <hildonmm.h>
+#    include <hildonmm/window.h>
 #endif
 
 #ifdef IS_HILDON
